@@ -58,6 +58,7 @@ Get the total number of postcodes for your progress bar:
 """
 
 
+from collections import OrderedDict
 import csv
 import fnmatch
 import glob
@@ -103,12 +104,12 @@ class BaseCodePoint(object):
     `CodePointDir`, or just forget about the difference and use `open_codepoint()`.
     """
 
-    root = 'Code-Point Open/'
+    root = ''
     headers_name = 'Doc/Code-Point_Open_Column_Headers.csv'
     metadata_name = 'Doc/metadata.txt'
     codelist_name = 'Doc/Codelist.xls'
     nhs_codelist_name = 'Doc/NHS_Codelist.xls'
-    data_name_format = 'Data/%s.csv'
+    data_name_format = 'Data/CSV/%s.csv'
     
     def entries(self, areas=None, to_proj=pyproj.Proj(init='epsg:4326')):
         """
@@ -124,17 +125,18 @@ class BaseCodePoint(object):
         """
 
         from_proj = pyproj.Proj(init='epsg:27700') # British National grid
-
+        
         if areas is None:
             areas = self.areas
-
+        
         for area in areas:
             if not re.search(r'^[A-Za-z]{1,2}$', area):
                 raise ValueError('Incorrect format for area: '
                                  'expected 1 or 2 letters, got "%s"' % (area,))
             
             for row in self._get_name_rows(self.data_name_format % area.lower()):
-                entry = dict(zip(self.long_headers, row))
+                entry = OrderedDict(zip(self.long_headers, row))
+                entry['_Area'] = area
 
                 if to_proj is not None:
                     eastings, northings = float(entry['Eastings']), float(entry['Northings'])
@@ -180,13 +182,13 @@ class CodePointZip(BaseCodePoint):
         self.zip_file = zipfile.ZipFile(zip_filename)
     
     def _open(self, name):
-        return self.zip_file.open(self.root + name)
+        return self.zip_file.open(name)
     
     def _read(self, name):
-        return self.zip_file.read(self.root + name)
+        return self.zip_file.read(name)
 
     def _get_areas(self):
-        pattern = self.root + (self.data_name_format % '*')
+        pattern = self.data_name_format % '*'
         return self._areas_from_names(
             name for name in self.zip_file.namelist()
             if fnmatch.fnmatch(name, pattern)
@@ -295,7 +297,6 @@ class Metadata(dict):
         raise ValueError('Can\'t get next mode from mode "%s" and line "%s"' % (mode, line,))
 
 
-
 class CodeList(dict):
     """
     The CodePoint download has a Doc/Codelist.xls Excel-format spreadsheet.
